summaryrefslogtreecommitdiff
path: root/boto/cloudsearch2/layer1.py
diff options
context:
space:
mode:
Diffstat (limited to 'boto/cloudsearch2/layer1.py')
-rw-r--r--boto/cloudsearch2/layer1.py26
1 files changed, 14 insertions, 12 deletions
diff --git a/boto/cloudsearch2/layer1.py b/boto/cloudsearch2/layer1.py
index fdc9d4c6..0c41762f 100644
--- a/boto/cloudsearch2/layer1.py
+++ b/boto/cloudsearch2/layer1.py
@@ -21,11 +21,11 @@
#
import boto
+from boto.compat import json
from boto.connection import AWSQueryConnection
from boto.regioninfo import RegionInfo
from boto.exception import JSONResponseError
from boto.cloudsearch2 import exceptions
-from boto.compat import json
class CloudSearchConnection(AWSQueryConnection):
@@ -56,6 +56,7 @@ class CloudSearchConnection(AWSQueryConnection):
"BaseException": exceptions.BaseException,
}
+
def __init__(self, **kwargs):
region = kwargs.pop('region', None)
if not region:
@@ -110,10 +111,10 @@ class CloudSearchConnection(AWSQueryConnection):
def define_analysis_scheme(self, domain_name, analysis_scheme):
"""
- Configures an analysis scheme for a domain. An analysis scheme
- defines language-specific text processing options for a `text`
- field. For more information, see `Configuring Analysis
- Schemes`_ in the Amazon CloudSearch Developer Guide .
+ Configures an analysis scheme that can be applied to a `text`
+ or `text-array` field to define language-specific text
+ processing options. For more information, see `Configuring
+ Analysis Schemes`_ in the Amazon CloudSearch Developer Guide .
:type domain_name: string
:param domain_name: A string that represents the name of a domain.
@@ -155,8 +156,8 @@ class CloudSearchConnection(AWSQueryConnection):
:type expression: dict
:param expression: A named expression that can be evaluated at search
- time. Can be used for sorting and filtering search results and
- constructing other expressions.
+ time. Can be used to sort the search results, define other
+ expressions, or return computed information in the search results.
"""
params = {'DomainName': domain_name, }
@@ -425,9 +426,12 @@ class CloudSearchConnection(AWSQueryConnection):
"""
Gets information about the search domains owned by this
account. Can be limited to specific domains. Shows all domains
- by default. For more information, see `Getting Information
- about a Search Domain`_ in the Amazon CloudSearch Developer
- Guide .
+ by default. To get the number of searchable documents in a
+ domain, use the console or submit a `matchall` request to your
+ domain's search endpoint:
+ `q=matchall&q.parser=structured&size=0`. For more information,
+ see `Getting Information about a Search Domain`_ in the Amazon
+ CloudSearch Developer Guide .
:type domain_names: list
:param domain_names: The names of the domains you want to include in
@@ -631,8 +635,6 @@ class CloudSearchConnection(AWSQueryConnection):
def list_domain_names(self):
"""
Lists all search domains owned by an account.
-
-
"""
params = {}
return self._make_request(